@@ -32,7 +32,7 @@
 
 #ifdef Q_OS_ANDROID
 #include "platforms/android/mauiandroid.h"
-#elif defined Q_OS_LINUX
+#elif (defined Q_OS_LINUX || defined Q_OS_FREEBSD)
 #include "platforms/linux/mauilinux.h"
 #endif
 
@@ -143,6 +143,10 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/MenuItemActionRow.qml")), uri, 1, 3, "MenuItemActionRow");
     qmlRegisterType(componentUrl(QStringLiteral("labs/GalleryRollTemplate.qml")), uri, 1, 3, "GalleryRollTemplate");
 
+    qmlRegisterType(componentUrl(QStringLiteral("SearchField.qml")), uri, 1, 0, "SearchField");
+    qmlRegisterType(componentUrl(QStringLiteral("PasswordField.qml")), uri, 1, 0, "PasswordField");
+    qmlRegisterType(componentUrl(QStringLiteral("ScrollView.qml")), uri, 1, 0, "ScrollView");
+    
     /// NON UI CONTROLS
     qmlRegisterUncreatableType<AppView>(uri, 1, 1, "AppView", "Cannot be created AppView");
     qmlRegisterUncreatableType<TabViewInfo>(uri, 1, 3, "TabViewInfo", "Cannot be created TabView");
@@ -163,19 +167,18 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsMac.qml")), uri, 1, 1, "WindowControls");
 #elif defined Q_OS_ANDROID
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
-#elif defined Q_OS_LINUX && !defined Q_OS_ANDROID
-
+#elif (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+    qmlRegisterType(componentUrl(QStringLiteral("labs/CSDControls.qml")), uri, 1, 1, "CSDControls");    
 #if defined Q_PROCESSOR_ARM
-    qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsLinux.qml")), uri, 1, 1, "WindowControls");
 #else
-    qmlRegisterType(componentUrl(QStringLiteral("labs/CSDControls.qml")), uri, 1, 1, "CSDControls");
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsLinux.qml")), uri, 1, 1, "WindowControls");
 #endif
 
 #endif
 
     /** PLATFORMS SPECIFIC CONTROLS **/
-#if defined Q_OS_LINUX || defined Q_OS_MACOS
+#if defined Q_OS_LINUX || defined Q_OS_FREEBSD || defined Q_OS_MACOS
     qmlRegisterType(componentUrl(QStringLiteral("Terminal.qml")), uri, 1, 0, "Terminal");
 #endif
 
@@ -185,7 +188,7 @@ void MauiKit::registerTypes(const char *uri)
         Q_UNUSED(scriptEngine)
         return new MAUIAndroid;
     });
-#elif defined Q_OS_LINUX
+#elif (defined Q_OS_LINUX || defined Q_OS_FREEBSD)
     qmlRegisterUncreatableType<MAUIKDE>(uri, 1, 0, "KDE", "Cannot be created KDE");
 #elif defined Q_OS_WIN32
     // here window platform integration interfaces
