@@ -26,7 +26,7 @@
 #include <QQuickWindow>
 #include <QQuickItem>
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 #include <KConfig>
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -149,7 +149,7 @@ MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
 
 CSDControls::CSDControls(QObject *parent) : QObject (parent)
 {
-#if !defined Q_OS_ANDROID || defined Q_OS_LINUX // ignore csd for those
+#if !defined Q_OS_ANDROID || defined Q_OS_LINUX || defined Q_OS_FREEBSD // ignore csd for those
     if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
     {
         if (QByteArrayList {"0", "false"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
@@ -165,7 +165,7 @@ CSDControls::CSDControls(QObject *parent) : QObject (parent)
 
 void CSDControls::getWindowControlsSettings()
 {    
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
     
     m_styleName = UTIL::loadSettings("CSDStyle", "GLOBAL", "Nitrux", true).toString();
     auto confFile = QStandardPaths::locate (QStandardPaths::GenericDataLocation, QString("org.mauikit.controls/csd/%1/config.conf").arg(m_styleName));
@@ -182,18 +182,20 @@ void CSDControls::getWindowControlsSettings()
     }
     
     qDebug() << "CSD QML SOURCXE" << m_source;
-    auto kconf = KSharedConfig::openConfig("kwinrc");
-    const auto group = kconf->group("org.kde.kdecoration2");
-    
-    if (group.hasKey("ButtonsOnLeft")) {
-        m_leftWindowControls = group.readEntry("ButtonsOnLeft", "").split("", Qt::SkipEmptyParts);
-        emit this->leftWindowControlsChanged();
-    }
-    
-    if (group.hasKey("ButtonsOnRight")) {
-        m_rightWindowControls = group.readEntry("ButtonsOnRight", "").split("", Qt::SkipEmptyParts);
-        emit this->rightWindowControlsChanged();
-    }
+    m_rightWindowControls =  QStringList {"I", "A", "X"};
+    emit this->rightWindowControlsChanged();
+//     auto kconf = KSharedConfig::openConfig("kwinrc");
+//     const auto group = kconf->group("org.kde.kdecoration2");
+//     
+//     if (group.hasKey("ButtonsOnLeft")) {
+//         m_leftWindowControls = group.readEntry("ButtonsOnLeft", "").split("", Qt::SkipEmptyParts);
+//         emit this->leftWindowControlsChanged();
+//     }
+//     
+//     if (group.hasKey("ButtonsOnRight")) {
+//         m_rightWindowControls = group.readEntry("ButtonsOnRight", "").split("", Qt::SkipEmptyParts);
+//         emit this->rightWindowControlsChanged();
+//     }
     
 #elif defined Q_OS_MACOS || defined Q_OS_ANDROID
     m_leftWindowControls = QStringList {"X", "I", "A"};
